# display, extcon, power, usb are always enabled

#Just For debugging
%define sdb_prestart off

Name:       deviced
Summary:    Deviced
Version:    5.0.0
Release:    1
Group:      System/Management
License:    Apache-2.0
Source0:    %{name}-%{version}.tar.gz
Source1:    deviced.manifest
Source2:    libdeviced.manifest

BuildRequires:  cmake
BuildRequires:  libattr-devel
BuildRequires:  gettext-devel
BuildRequires:  pkgconfig(mount)
BuildRequires:  pkgconfig(vconf)
BuildRequires:  pkgconfig(dlog)
BuildRequires:  pkgconfig(device-node)
BuildRequires:  pkgconfig(capi-base-common)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(eventsystem)
BuildRequires:  pkgconfig(libtzplatform-config)
BuildRequires:  pkgconfig(hwcommon)
BuildRequires:  pkgconfig(capi-system-info)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libinput)
BuildRequires:	pkgconfig(capi-system-sensor)
BuildRequires:	pkgconfig(fuse)
BuildRequires:	pkgconfig(minizip)
BuildRequires:	pkgconfig(libkmod)
BuildRequires:	pkgconfig(libusbgx)
BuildRequires:	pkgconfig(libgdbus)
BuildRequires:	pkgconfig(capi-system-device)

Requires: %{name}-tools = %{version}-%{release}
%{?systemd_requires}
Requires(post): /usr/bin/vconftool

%description
deviced

%package -n libdeviced
Summary:    Deviced library
Group:      Development/Libraries
Requires:   %{name} = %{version}-%{release}

%description -n libdeviced
Deviced library for device control.
Libdeviced is profile-independent; i.e., every profile has the same
binary for libdeviced.

%package -n libdeviced-devel
Summary:    Deviced library for (devel)
Group:      Development/Libraries
Requires:   libdeviced = %{version}-%{release}

%description -n libdeviced-devel
Deviced library for device control (devel).
Because this is internal interface, every profile MUST have the same
devel package.

%package tools
Summary:    Deviced tools
Group:      System/Utilities

%description tools
Deviced helper programs.
Deviced-tools is profile-independent; i.e., every profile has the same
binary for deviced-tools.

%package auto-test
Summary:    Deviced auto test tool
Group:      System/Utilities

%description auto-test
Deviced helper programs.
This package can be installed optional for auto dbus test.

%package config-profile-wearable
Summary:    Configuration files for wearable profile
Group:      System/Management
BuildArch:  noarch

%description config-profile-wearable
This package is used for wearable profile

%package config-enable-display-timer
Summary:    Configuration files for display
Group:      System/Management
BuildArch:  noarch

%description config-enable-display-timer
This package is used for enabling a display timer.

%package plugin-profile-tv
Summary:    Plugin libraries for TV profile
Group:      System/Management
Requires:   %{name} = %{version}-%{release}

%description plugin-profile-tv
Plugin libraries for TV profile

%prep
%setup -q

%ifarch %{arm} aarch64
	%define ARCH arm
%endif

%ifarch %{arm} %ix86
	%define ARCH_BIT 32
%else
	%define ARCH_BIT 64
%endif

%if 0%{?tizen_build_devel_mode} == 1
%define engineer_mode on
%else
%define engineer_mode off
%endif

%cmake \
	-DTZ_SYS_ETC=%TZ_SYS_ETC \
	-DCMAKE_INSTALL_PREFIX=%{_prefix} \
	-DARCH=%{ARCH} \
	-DARCH_BIT=%{ARCH_BIT} \
	-DDPMS=%{DPMS} \
	-DENGINEER_MODE=%{engineer_mode} \
	-DBATTERY_MODULE=on \
	-DDISPLAY_MODULE=on \
	-DEXTCON_MODULE=on \
	-DIR_MODULE=on \
	-DLED_MODULE=on \
	-DPOWER_MODULE=on \
	-DSDB_PRESTART=%{sdb_prestart} \
	-DTOUCHSCREEN_MODULE=on \
	-DTZIP_MODULE=on \
	-DUSB_MODULE=on \
	-DUSBHOST_MODULE=on \
	-DTHERMAL_MODULE=on \
	-DTIZEN_FEATURE_CPU_MODULE=on \
	-DTIZEN_FEATURE_USBHOST_TEST=on \
	-DTIZEN_FEATURE_BATTERY_OVER_TEMPERATURE=on \
	#eol

%build
cp %{SOURCE1} .
cp %{SOURCE2} .

make %{?jobs:-j%jobs}

%install
rm -rf %{buildroot}
%make_install

%install_service multi-user.target.wants deviced.service
# usb_module condition is removed because it is always on
%if %{?sdb_prestart} == on
%install_service basic.target.wants sdb-prestart.service
%endif

mkdir -p %{buildroot}%{TZ_SYS_DUMPGEN}
install -m 775 scripts/dump_pmstate_log.sh %{buildroot}%{TZ_SYS_DUMPGEN}/dump_pmstate_log.sh

%post
#memory type vconf key init
users_gid=$(getent group %{TZ_SYS_USER_GROUP} | cut -f3 -d':')

systemctl daemon-reload
if [ "$1" == "1" ]; then
    systemctl restart deviced.service
fi

%postun
systemctl daemon-reload
if [ "$1" == "0" ]; then
    systemctl stop deviced.service
fi

%post -n libdeviced -p /sbin/ldconfig

%postun -n libdeviced -p /sbin/ldconfig

%post config-profile-wearable
cat %{_sysconfdir}/deviced/display-profile-wearable.conf >> %{_sysconfdir}/deviced/display.conf
rm -rf %{_sysconfdir}/deviced/display-profile-wearable.conf

%post config-enable-display-timer
cat %{_sysconfdir}/deviced/display-enable-timer.conf >> %{_sysconfdir}/deviced/display.conf
rm -rf %{_sysconfdir}/deviced/display-enable-timer.conf

%post plugin-profile-tv
mkdir -p %{_libdir}/deviced
mv %{_libdir}/display-tv.so %{_libdir}/deviced/display.so

%postun plugin-profile-tv

%files
%manifest %{name}.manifest
%license LICENSE.Apache-2.0
%{_bindir}/deviced
%{_unitdir}/multi-user.target.wants/deviced.service
%{_unitdir}/deviced.service
%{_datadir}/dbus-1/system-services/org.tizen.system.deviced.service
%if %{?sdb_prestart} == on
%{_unitdir}/sdb-prestart.service
%{_unitdir}/basic.target.wants/sdb-prestart.service
%endif
%config %{_sysconfdir}/dbus-1/system.d/org.tizen.system.deviced.conf
%config %{_sysconfdir}/deviced/cpu.conf
%config %{_sysconfdir}/deviced/power.conf
%config %{_sysconfdir}/deviced/battery.conf
%config %{_sysconfdir}/deviced/display.conf
%config %{_sysconfdir}/deviced/usb-operation.conf
# usbhost_test
%{_sysconfdir}/deviced/usb-host-test/test_gadget.gs
%{_bindir}/usb-host-ffs-test-daemon
%{_unitdir}/usb-host-ffs-test-daemon.service
%{_unitdir}/usb-host-test.socket
%{_sysconfdir}/deviced/usb-host-test/descs
%{_sysconfdir}/deviced/usb-host-test/strs

%files -n libdeviced
%manifest deviced.manifest
%license LICENSE.Apache-2.0
%defattr(-,root,root,-)
%{_libdir}/libdeviced.so.*

%files -n libdeviced-devel
%defattr(-,root,root,-)
%{_includedir}/deviced/*.h
%{_libdir}/libdeviced.so
%{_libdir}/pkgconfig/deviced.pc

%files tools
%manifest deviced.manifest
%license LICENSE.Apache-2.0
%{_bindir}/devicectl
#if #{?usb_module} == on ==> always on
%{_bindir}/direct_set_debug.sh
%{TZ_SYS_DUMPGEN}/dump_pmstate_log.sh
#endif

%files auto-test
%manifest deviced.manifest
%license LICENSE.Apache-2.0
%{_bindir}/deviced-auto-test
%config %{_sysconfdir}/deviced/auto-test.conf

%files config-profile-wearable
%manifest deviced.manifest
%license LICENSE.Apache-2.0
%config %{_sysconfdir}/deviced/display-profile-wearable.conf

%files config-enable-display-timer
%manifest deviced.manifest
%license LICENSE.Apache-2.0
%config %{_sysconfdir}/deviced/display-enable-timer.conf

%files plugin-profile-tv
%manifest deviced.manifest
%license LICENSE.Apache-2.0
%defattr(-,root,root,-)
%{_libdir}/display-tv.so
